finalizers

package
v0.8.49 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Ensure

func Ensure(ctx context.Context, c client.Client, obj client.Object, name string) error

Ensure adds the finalizer to the object if missing and patches it. Safe to call repeatedly. It performs a server-side patch to avoid conflicts.

func Has

func Has(obj client.Object, name string) bool

Has returns true if the object has the finalizer name.

func Remove

func Remove(ctx context.Context, c client.Client, obj client.Object, name string) error

Remove removes the finalizer from the object if present and patches it. Safe to call repeatedly.

Types

This section is empty.

Jump to